<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Простой и удобный клиент для Jabber/XMPP</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Лицензия:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="obsolete">Исходный код на GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Просмотреть исходный код онлайн</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Сообщить о проблемах</translation>
    </message>
</context>
<context>
    <name>AboutPage</name>
    <message>
        <source>About</source>
        <translation type="vanished">О программе</translation>
    </message>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Простой и удобный Jabber/XMPP клиент</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Лицензия:</translation>
    </message>
    <message>
        <source>Sourcecode on GitHub</source>
        <translation type="vanished">Исходный код на GitHub</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Закрыть</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Простой и удобный Jabber/XMPP клиент</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Лицензия:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Исходный код на GitHub</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Удалить аккаунт отовсюду</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">Ваша учётная запись будет удалена в приложении и на сервере. 
Вы больше не сможете ей пользоваться!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Удалить</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">Удалить аккаунт в приложении</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">Ваша учётная запись будет удалена в приложении.
Учётные данные нельзя восстановить!
Cохраните их, если планируете использовать её в дальнейшем.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Удалить</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Удалить аккаунт</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">Учётную запись &lt;b&gt;%1&lt;/b&gt; можно удалить в приложении или полностью отовсюду. В последнем случае ей нельзя будет пользоваться в других приложениях, потому что она удаляется на сервере тоже.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">Удалить в приложении</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Удалить отовсюду</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Безопасность учётной записи</translation>
    </message>
    <message>
        <source>Allow to add additional devices using the login QR code but never show the password.</source>
        <translation>Разрешить авторизацию с других устройств с помощью QR-кода, но никогда не показывать пароль на экране.</translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation>Не показывать пароль на экране</translation>
    </message>
    <message>
        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
        <translation>Запретить авторизацию с других устройств с помощью QR-кода и никогда не показывать пароль на экране.</translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation>Не позволять узнать пароль никаким способом</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Перенести учётную запись на другое устройство</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Отсканируйте QR-код или введите учётные данные на другом устройстве, чтобы выполнить вход.

Важно:
Никому не показывайте этот QR-код! С помощью него злоумышленники могут получить неограниченный доступ к вашей учётной записи!</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Скрыть QR-код</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Показать как QR-код</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Скрыть текст</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Показать как текст</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Копировать пароль</translation>
    </message>
    <message>
        <source>Copy chat address</source>
        <translation>Копировать адрес</translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Назад</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Изменить пароль</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Текущий пароль:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Новый пароль:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Новый пароль (повторно):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Пароли не совпадают.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Текущий пароль введён неправильно.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">Чтобы изменить пароль нужно быть в сети.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>После изменения пароля вам придётся ввести его заново на всех других устройствах.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation>Пароль успешно изменён</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Не удалось изменить пароль: %1</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Spoiler</source>
        <translation>Спойлер</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Скачать</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Копировать текст сообщения</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Изменить сообщение</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Копировать ссылку на скачивание</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Цитировать сообщение</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">Создать сообщение</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Отправить</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Изображение</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Видео</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Звук</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Документ</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Другой файл</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Выберите файл</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Отправить спойлер</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="vanished">Подсказка к спойлеру</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Включить уведомления</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Отключить уведомления</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Посмотреть профиль</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Закрыть</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Искать выше</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Искать ниже</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">Все файлы</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Скопировать сообщение</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Редактировать сообщение</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Скопировать URL загрузки</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Цитировать сообщение</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation>Закрыть панель поиска</translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation>Описание спойлера</translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation>Закрыть описание спойлера</translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation>Написать сообщение</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Вашу учётную запись не удалось удалить на сервере, поэтому из приложения она также не была удалена: %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Очень низкое</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Низкое</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Обычное</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Высокое</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Очень высокое</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Постоянное качество</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Постоянный битрейт</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Средний битрейт</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Двухпроходный</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation>Настройки подключения</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation>Не удалось изменить настройки подключения</translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation>Настройки подключения изменены</translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Действия</translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation>Имя узла не может содержать пробелы</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Don&apos;t expose your password in any way</source>
        <translation>Не позволять узнать пароль никаким способом</translation>
    </message>
    <message>
        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device.</source>
        <translation>Ваш пароль больше никогда не будет показан на экране или в QR-коде для авторизации.
Вы больше не сможете использовать вход через QR-код без ввода пароля, потому что это действие не может быть отменено!
Если вы хотите использовать аккаунт на другом устройстве, задумайтесь над тем, чтобы сохранить пароль где-либо ещё.</translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation>Не позволять узнать пароль никаким способом</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Don&apos;t show your password</source>
        <translation>Не показывать пароль на экране</translation>
    </message>
    <message>
        <source>Your password will not be shown anymore but still exposed via the login QR code.
You won&apos;t be able to see your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
        <translation>Ваш пароль больше никогда не будет показан на экране, но он будет включён в QR-код для авторизации.
Вы больше не сможете увидеть свой пароль, потому что это действие не может быть отменено!
Если вы хотите использовать аккаунт на устройстве, не имеющем возможности сканирования QR-кода, задумайтесь над тем, чтобы сохранить пароль где-либо ещё.</translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation>Не показывать пароль на экране</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Не удалось сохранить файл: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Не удалось загрузить: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">Избранное</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">Люди</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">Природа</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">Еда</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">Деятельность</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">Путешествия</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">Объекты</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">Символы</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">Флаги</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Поиск</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">Поиск эмодзи</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Чтобы начать обмен сообщениями, выберите чат</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="obsolete">Выберите файл</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Close</source>
        <translation type="obsolete">Закрыть</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Вперёд</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Выйти</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="vanished">Добавить контакт</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Назад</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Пригласить друзей</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Ссылка на приглашение скопирована в буфер обмена</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Не в сети</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>В сети</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Поключение…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Перенести учётную запись</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Удалить учётную запись</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Переключиться на другое устройство</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Ссылка будет открыта после подключения.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation type="vanished">QR код для входа не найден.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Удалить аккаунт из приложения</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>Ваш аккаунт будет удалён из этого приложения.
Ваш пароль также будет удалён, поэтому убедитесь, что он сохранён в диспетчере паролей или вы его знаете!</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Ваш Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">ivanov@example.ru</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Ваш пароль:</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">Пароль</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Повторить</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">Подключиться</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Подключение…</translation>
    </message>
    <message>
        <source>Log in</source>
        <translation>Вход</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Войдите в аккаунт XMPP</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Ваш ID в diaspora*:</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">пользователь@diaspora.pod</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Неверное имя пользователя или пароль.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Не удается подключиться к серверу. Пожалуйста, проверьте подключение к Интернету.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Сервер не поддерживает безопасные соединения.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Ошибка при попытке надежного подключения.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Не смог определить адрес сервера. Пожалуйста, проверьте ваш JID еще раз.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Не смог подключиться к серверу.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Протокол аутентификации не поддерживается сервером.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Произошла неизвестная ошибка; подробности см. в журнале.</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation>Настройки подключения</translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation>Настройки подключения</translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation>Настройки подключения будут сохранены после первого успешного входа. Если не удастся наладить соединение, вы снова окажетесь на странице авторизации.</translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation>Использовать пользовательские настройки подключения</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Сфотографировать</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Записать видео</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Записать аудио</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Оправить местоположение</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Выбрать файл</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Выбрать изображение</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Выбрать видео</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Выбрать аудиозапись</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Выбрать документ</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудиофайл</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Документ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation>Спойлер</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Сообщение не отправлено (отсутствует подключение к сети).</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Исправить сообщение не получилось (отсутствует подключение к сети).</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Спойлер</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Не удалось отправить сообщение.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Не удалось изменить сообщение.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>Ожидает отправки</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Отправлено</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Доставлено</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Настройки мультимедиа</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Захват изображения</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Запись аудио</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Запись видео</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Аудио вход</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Контейнер</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Частота дискретизации</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Частота кадров</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Инициализация…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Недоступно</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Запись…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Image</source>
        <translation type="obsolete">Изображение</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Звук</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="obsolete">Видео</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="vanished">Готово</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Инициализация…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Недоступно</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Запись… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>Пауза %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Удалить пароль</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Вы можете запретить показывать пароль учётной записи &lt;b&gt;%1&lt;/b&gt; на экране или полностью удалить его. Если полностью удалить пароль, вы больше не сможете перенести аккаунт через сканирование кода без ввода пароля, так как он будет удалён в том числе из QR-кода.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Не показывать пароль на экране</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Полностью удалить</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Отметить как прочитанное</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Онлайн</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>В настроении пообщаться</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Отсутствует</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Не беспокоить</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Отсутствует надолго</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Не в сети</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="vanished">Доступен</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">В настроении поболтать</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Отошёл</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Не беспокоить</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Ушёл надолго</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Не в сети</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Ошибка</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Невидимый</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Неверное имя пользователя или пароль.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Не удалось подключиться к серверу. Пожалуйста, проверьте подключение к сети.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>Сервер не поддерживает защищённое соединение.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Ошибка при попытке установить защищённое соединение.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="vanished">Не удалось преобразовать адрес сервера. Пожалуйста, проверьте имя сервера.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Не смог подключиться к серверу.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Сервер не поддерживает этот протокол аутентификации.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Этот сервер не поддерживает регистрацию.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>Этот сервер не работает или заблокирован сетевым экраном.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>Не удалось обновить соединение.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>Доступ в сеть закрыт. Пожалуйста, проверьте системные настройки доступа в интернет.</translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation>Не удалось подключиться к серверу. Проверьте подключение к сети и имя узла сервера.</translation>
    </message>
    <message>
        <source>%1 is online</source>
        <translation>%1 в сети</translation>
    </message>
    <message>
        <source>%1 is typing…</source>
        <translation>%1 набирает сообщение…</translation>
    </message>
    <message>
        <source>%1 paused typing</source>
        <translation>%1 делает паузу</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Не удалось сгенерировать QR код: %1</translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Cканировать QR-код</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Показать пояснения</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Продолжить без QR-кода</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Чтобы перенести учётную запись, сканируйте код c другого устройства.</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Подключение…</translation>
    </message>
    <message>
        <source>This QR code is not a valid login QR code.</source>
        <translation>Этот QR-код недействителен для входа в аккаунт.</translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>Формат камеры &apos;%1&apos; не поддерживается.</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Не удалось обнаружить камеру.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Камера уже используется.
Попробуйте закрыть приложения, использующие камеру.</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">Отсканировать QR код</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="vanished">Не удалось обнаружить камеру.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="vanished">Камера занята.
Попробуйте закрыть другие приложения, использующие камеру.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="vanished">Формат камеры &apos;%1&apos; не поддерживается.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">Вход в систему…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="vanished">Чтобы перенести учётную запись, отсканируйте код другим устройством.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="vanished">Показать пояснения</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">Сканировать</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">Продолжить без QR кода</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Зарегистрироваться</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Войти в учётную запись</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="vanished">Пароль изменён.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="vanished">Не удалось изменить пароль: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Полностью удалить учётную запись</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Ваша учётная запись будет удалена полностью: и в приложении, и на сервере.
Вы больше не сможете ей пользоваться!</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Nickname:</source>
        <translation>Имя (ник):</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Jabber ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>user@example.org</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Также будет отправлен запрос на доступ к статусу контакта.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Сообщение (необязательно):</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Расскажите собеседнику, кто вы.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Offline</source>
        <translation type="obsolete">Не в сети</translation>
    </message>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="vanished">Ошибка: пожалуйста, проверьте JID.</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Невозможно добавить контакт, так как он не подключён.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Не удалось удалить контакт из-за отсутствия подключения.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Спойлер</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Не удалось переименовать контакт из-за отсутствия подключения.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Соединение…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Не в сети</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Искать в контактах</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">Вы действительно хотите удалить контакт &quot;%1&quot; из своего списка?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Удалить контакт</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="vanished">Хотите удалить контакт &lt;b&gt;%1&lt;/b&gt; из списка?</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation>Вы действительно хотите удалить контакт &lt;b&gt;%1&lt;/b&gt; из списка?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Переименовать контакт</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Подпись</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Другой сервер</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Без ограничений</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 дней</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Изменить пароль</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Изменяет пароль учётной записи. Вам придётся ввести его заново на других устройствах.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Настройки мультимедиа</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Изменить настройки фотографий, аудио- и видеозаписей</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Безопасность аккаунта</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Удалить аккаунт из приложения Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Удалить аккаунт из приложения</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Удалить аккаунт</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Удалить аккаунт на сервере</translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation>Настройки подключения</translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation>Настройте имя узла сервера и порт для подключения</translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on another device</source>
        <translation>Может ли это устройство быть использовано, чтобы авторизоваться с другого устройства</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Настройки</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Свободное общение на любом устройстве!</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>Начнём</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Запрос на подписку</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Вы получили запрос на подписку от &lt;b&gt;%1&lt;/b&gt;. Если вы его примете, у контакта будет доступ к вашему статусу.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Отклонить</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Не удалось отправить файл из-за отсутствия соединения.</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Файл</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Не удалось отправить сообщение.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Профиль</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Переименовать контакт</translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation>Показать QR-код</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Удалить контакт</translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation>Устройства в сети</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Имя (ник)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Электронная почта</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Дата рождения</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Successfully parsed command line input.</source>
        <translation type="vanished">Ввод из командной строки успешно распознан.</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation type="vanished">Выйти</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">О программе</translation>
    </message>
</context>
</TS>
